pub struct TimeAttestation {
pub authority: String,
pub artifact_hash: String,
pub attested_at: DateTime<Utc>,
pub external_anchor: Vec<u8>,
pub signature: Vec<u8>,
}Expand description
A time authority’s attestation over an artifact.
Fields
The time authority’s identifier.
artifact_hash: StringThe artifact’s canonical payload hash (hex).
attested_at: DateTime<Utc>When the authority attests the artifact existed.
external_anchor: Vec<u8>The external anchor: serialized OpenTimestamps proof (or equivalent) binding the hash to an irrefutable time source.
signature: Vec<u8>The time authority’s signature over the attestation body.
Implementations
Sourceimpl TimeAttestation
impl TimeAttestation
Sourcepub fn signing_bytes(&self) -> SignatifResult<Vec<u8>>
pub fn signing_bytes(&self) -> SignatifResult<Vec<u8>>
Sourcepub fn verify(
&self,
authority_key: &[u8],
verifier: &dyn SignatureVerifier,
) -> SignatifResult<()>
pub fn verify( &self, authority_key: &[u8], verifier: &dyn SignatureVerifier, ) -> SignatifResult<()>
Verify the attestation: the authority’s signature, and that an external anchor is present (the anchor itself is verified against the time source by the OTS layer).
Errors
Signature or anchor errors.